@@ -21,6 +21,7 @@
 
 KNetworkConf::KNetworkConf(QWidget *parent, const char *name) : DCOPObject("KNetworkConfIface"), KNetworkConfDlg(parent, name)
 {
+  netInfo = 0L;
   makeButtonsResizeable();
   config = new KNetworkConfigParser();
   klvCardList->setAllColumnsShowFocus(true);
@@ -62,7 +63,7 @@ void KNetworkConf::getNetworkInfoSlot()
   if (netInfo == NULL)
   {
     KMessageBox::error(this,
-                        i18n("Could not load network info."),
+                        i18n("Could not load network configuration information."),
                         i18n("Error Reading Configuration File"));
     //kapp->quit();
     //exit(1);
@@ -262,7 +263,12 @@ void KNetworkConf::configureDeviceSlot(){
     }
     configDlg.addDlg->kleIPAddress->setText(dev->getIpAddress());
     advancedOptions->kleDescription->setText(dev->getDescription());
-    advancedOptions->kleBroadcast->setText(dev->getBroadcast());
+    if (!dev->getBroadcast().isEmpty())
+      advancedOptions->kleBroadcast->setText(dev->getBroadcast());
+    else
+      advancedOptions->kleBroadcast->setText(KAddressValidator::calculateBroadcast(dev->getIpAddress(),dev->getNetmask()));
+      
+    advancedOptions->kleGateway->setText(dev->getGateway());
 
     if (!dev->getNetmask().isEmpty())
       configDlg.addDlg->kcbNetmask->setCurrentText(dev->getNetmask());
@@ -296,7 +302,7 @@ void KNetworkConf::configureDeviceSlot(){
       if(configDlg.addDlg->rbBootProtoManual->isChecked())
       {
         item->setText(2,i18n("Manual"));
-	dev->setBootProto("none");
+	      dev->setBootProto("none");
       }
       //If the selected boot protocol is dhcp or bootp (Auto), then we don't need the
       //past IP address, netmask, network and broadcast, as a new one will be assigned by
@@ -307,6 +313,7 @@ void KNetworkConf::configureDeviceSlot(){
         {
           dev->setIpAddress("");
           configDlg.addDlg->kleIPAddress->setText("");
+          dev->setGateway("");
           dev->setNetmask("");
           dev->setNetwork("");
           dev->setBroadcast("");
@@ -321,18 +328,18 @@ void KNetworkConf::configureDeviceSlot(){
                         configDlg.addDlg->kcbAutoBootProto->currentText(),
                         configDlg.addDlg->kcbNetmask->currentText(),
                         configDlg.addDlg->kleIPAddress->text(),
+                        advancedOptions->kleGateway->text(),
                         configDlg.addDlg->kcbstartAtBoot->isChecked(),
-	 		advancedOptions->kleDescription->text(),
-		  	advancedOptions->kleBroadcast->text()))
+	 		                  advancedOptions->kleDescription->text(),
+		  	                advancedOptions->kleBroadcast->text()))
         {
           dev->setIpAddress(configDlg.addDlg->kleIPAddress->text().stripWhiteSpace());
+          dev->setGateway(advancedOptions->kleGateway->text().stripWhiteSpace());
           dev->setNetmask(configDlg.addDlg->kcbNetmask->currentText().stripWhiteSpace());
           QString network = KAddressValidator::calculateNetwork(dev->getIpAddress().stripWhiteSpace(),dev->getNetmask().stripWhiteSpace());
           dev->setNetwork(network);
-          QString broadcast;
-          if (configDlg.advanced())
-	          broadcast = advancedOptions->kleBroadcast->text().stripWhiteSpace();
-        else
+          QString broadcast = advancedOptions->kleBroadcast->text().stripWhiteSpace();
+          if (broadcast.isEmpty())
             broadcast = KAddressValidator::calculateBroadcast(dev->getIpAddress().stripWhiteSpace(),dev->getNetmask().stripWhiteSpace());
           dev->setBroadcast(broadcast);
           dev->setDescription(advancedOptions->kleDescription->text());
@@ -397,21 +404,36 @@ void KNetworkConf::readFromStdout(){
 /** Loads the info about the default gateway and host and domain names. */
 void KNetworkConf::loadRoutingInfo(){
   //routingInfo = config->getNetworkInfoSlot();
-  if (routingInfo == NULL)
-    KMessageBox::error(this,i18n("Could not open file '/etc/sysconfig/network' for reading."),
-                        i18n("Error Loading Config Files"));
+  if (!routingInfo->getGateway().isEmpty())
+    kleDefaultRoute->setText(routingInfo->getGateway());
   else
   {
-    kleDefaultRoute->setText(routingInfo->getGateway());
-    kcbGwDevice->clear();
-    kcbGwDevice->insertStringList(deviceNamesList);
-    if (!routingInfo->getGatewayDevice().isEmpty())
-      kcbGwDevice->setCurrentText(routingInfo->getGatewayDevice());
-/*    if (routingInfo->isForwardIPv4Enabled().compare("yes") == 0)
+    //Take the default gateway from the gateway field of the default gateway interface
+    //because some platforms (Debian-like ones) seems that don't handle the concept of a default 
+    //gateway, instead a gateway per interface.
+    KNetworkInterface *device;
+    QString defaultGwDevice = routingInfo->getGatewayDevice();
+    QPtrList<KNetworkInterface> deviceList = netInfo->getDeviceList();
+    for (device = deviceList.first(); device; device = deviceList.next())
+    {  
+      if ( device->getDeviceName() == defaultGwDevice )
+      {
+        if ( !device->getGateway().isEmpty() )  
+        {
+          kleDefaultRoute->setText(device->getGateway());
+        }
+      }
+    }    
+  }  
+    
+  kcbGwDevice->clear();
+  kcbGwDevice->insertStringList(deviceNamesList);
+  if (!routingInfo->getGatewayDevice().isEmpty())
+    kcbGwDevice->setCurrentText(routingInfo->getGatewayDevice());
+/*  if (routingInfo->isForwardIPv4Enabled().compare("yes") == 0)
       cbEnableRouting->setChecked(true);
     else
       cbEnableRouting->setChecked(false);*/
-  }
 }
 
 void KNetworkConf::loadDNSInfo(){
@@ -589,6 +611,24 @@ void KNetworkConf::saveInfoSlot(){
     netInfo->setRoutingInfo(routingInfo);
     netInfo->setDNSInfo(dnsInfo);
 
+    //Add the default gateway to the gateway field of the default gateway interface
+    //because some platforms (Debian-like ones) get the default gateway from there 
+    //instead from the default gateway field. funny huh?
+    KNetworkInterface *device;
+    QString defaultGwDevice = routingInfo->getGatewayDevice();
+    QString defaultGwAddress = routingInfo->getGateway();
+    QPtrList<KNetworkInterface> deviceList = netInfo->getDeviceList();
+    for (device = deviceList.first(); device; device = deviceList.next())
+    {  
+      if ( device->getGateway().length() == 0 )
+      {
+        if ( device->getDeviceName() == defaultGwDevice )  
+        {
+          device->setGateway(defaultGwAddress);
+        }
+      }
+    }  
+    
     config->saveNetworkInfo(netInfo);
     modified = false;
   }
@@ -751,12 +791,14 @@ bool KNetworkConf::valuesChanged(KNetworkInterface *dev,
                                   QString bootProto,
                                   QString netmask,
                                   QString ipAddr,
+                                  QString gateway,
                                   bool onBoot,
                                   QString desc,
 				  QString broadcast){
   if ((dev->getBootProto() != bootProto) ||
       (dev->getNetmask() != netmask) ||
       (dev->getIpAddress() != ipAddr) ||
+      (dev->getGateway() != gateway) ||
       ((dev->getOnBoot() == "yes") && !(onBoot)) ||
       ((dev->getOnBoot() == "no") && (onBoot)) ||
       (dev->getDescription() != desc) ||
@@ -990,6 +1032,8 @@ KNetworkInfo *KNetworkConf::getProfile(QPtrList<KNetworkInfo> profilesList, QStr
 
 void KNetworkConf::createProfileSlot()
 {
+  if (!netInfo)
+		  return;
   bool ok;
   QString newProfileName = KInputDialog::getText(i18n("Create New Network Profile"), 
                                         i18n("Name of new profile:"), 
@@ -1055,9 +1099,9 @@ void KNetworkConf::removeProfileSlot()
   QListViewItem *item= klvProfilesList->selectedItem();
   if (item != NULL)
   {
-    if (KMessageBox::warningContinueCancel(this,
+/*    if (KMessageBox::warningContinueCancel(this,
                         i18n("Are you sure you want to delete the selected network profile?"),
-                        i18n("Delete Profile"),KStdGuiItem::del()) == KMessageBox::Continue)
+                        i18n("Delete Profile"),KStdGuiItem::del()) == KMessageBox::Continue)*/
     {                    
       QString selectedProfile = item->text(0);
       QPtrList<KNetworkInfo> profiles = netInfo->getProfilesList();
@@ -1088,6 +1132,7 @@ void KNetworkConf::updateProfileSlot()
     QString selectedProfile = item->text(0);
     QPtrList<KNetworkInfo> profiles = netInfo->getProfilesList();
     KNetworkInfo *profileToUpdate = NULL;
+    KNetworkInfo *newProfile = new KNetworkInfo();
   
     for ( profileToUpdate = profiles.first(); profileToUpdate; profileToUpdate = profiles.next() )
     {
@@ -1095,11 +1140,20 @@ void KNetworkConf::updateProfileSlot()
       if (profileName == selectedProfile)
       { 
         qDebug("profile updated");
+        newProfile->setProfileName(profileName);
+        newProfile->setDNSInfo(netInfo->getDNSInfo());
+        newProfile->setDeviceList(netInfo->getDeviceList());
+        newProfile->setNetworkScript(netInfo->getNetworkScript());
+        newProfile->setPlatformName(netInfo->getPlatformName());
+        newProfile->setProfilesList(netInfo->getProfilesList());
+        newProfile->setRoutingInfo(netInfo->getRoutingInfo());
+  
+        
         profileToUpdate = netInfo;   
         int curPos = profiles.at();
-        profileToUpdate->setProfileName(profileName);   
+  //      profileToUpdate->setProfileName(profileName);   
         profiles.remove();
-        profiles.insert(curPos,profileToUpdate);
+        profiles.insert(curPos,newProfile);
         netInfo->setProfilesList(profiles);
         modified = false;        
         enableApplyButtonSlot();
