@@ -19,8 +19,8 @@
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program in a file called COPYING; if not, write to
-** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-** MA 02111-1307, USA.
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
 */
 
 /*
@@ -93,7 +93,10 @@ public:
   pkgInterface *pkType(const QString &fname);
   // find type of package
 
-  void openNetFiles(QStringList urls, bool install=TRUE);
+  int typeIndex(pkgInterface *);
+  // convert interface pointer to index
+  
+  void openNetFiles(const QStringList &urls, bool install=TRUE);
   void openNetFile(const KURL & url, bool install=TRUE);
   // open a file given a URL
 
@@ -324,7 +327,7 @@ extern QString hostName;
 
 extern pkgInterface *kpinterface[];
 
-void KpMsg(QString lab, QString msg, bool stop);
-void KpMsgE(QString msg, bool stop = FALSE);
+void KpMsg(const QString &lab, const QString &msg, bool stop);
+void KpMsgE(const QString &msg, bool stop = FALSE);
 #endif
 
