@@ -92,6 +92,11 @@ int main(int argc, char **argv)
   kpkg = 0;
   int j = 0;
 
+// Make sure PATH has the right directories in it
+  QCString path = getenv("PATH");
+  path = "PATH=" + path + ":/sbin:/usr/sbin:/usr/local/bin";
+  putenv(strdup(path.data()));
+	 
   KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
   QString remoteHost = args->getOption("remote");
 
